\name{absFilter}
\alias{absFilter}
\title{ABS filter}
\description{Identify amplification-biased sites in allele-specific analysis of ChIP-seq data.}
\usage{
absFilter(bamPath, bamFile, asPath, asFile, absPath, absSim, absGlobal = 5, absLocal = 0.05)
}
\arguments{
  \item{bamPath}{path to folder with BAM files}
  \item{bamFile}{BAM file}
  \item{asPath}{path to folder with SNP files}
  \item{asFile}{tab-delimited file with information about SNP sites. The first four columns must contain the following information: CHR, START, END, RSID (e.g. chr9	272980	272981	rs2992835)}
  \item{absPath}{path to save output files}
  \item{absSim}{an object loaded with the loadSim function}
  \item{absGlobal}{minimum number of URSSs per SNP site for the global filter (default: 5)}
  \item{absLocal}{the p-value cutoff for the local filter (default: 0.05)}
}

\value{
	absFilter returns a list with two objects. Each object corresponds to the input asFile split into:
	\item{aubs}{amplification unbiases sites}
	\item{abs}{amplification biased sites}
}

\author{
Sebastian M Waszak
}

\examples{
### download URSS simulations for 36 bp reads from http://updepla1srv1.epfl.ch/waszaks/ and uncompress it to /path/to/abs/sim/36/
### load URSS simulations for 36 bp reads (approx. 1GB memory footprint).
absSim36 <- loadSim(path = "/path/to/abs/sim/36/")

### run ABS filter on example.bam and with the corresponding AS file example.txt
absFiltOut <- absFilter(bamPath = "/path/to/bam/dir/",
                        bamFile = "example.bam",
                        asPath = "/path/to/as/dir/",
                        asFile = "example.txt",
                        absPath = "/path/to/abs/out/dir/",
                        absSim = absSim36)

absFiltOutUnbiasedSites<- absFiltOut$aubs # amplification unbiased sites
absFiltOutBiasedSites<- absFiltOut$abs    # amplification biased sites
nrow(absFiltOutUnbiasedSites)
nrow(absFiltOutBiasedSites)
}
