\name{absfilter-package}
\alias{absfilter-package}
\alias{absfilter}
\docType{package}
\title{ABS filter for ChIP sequencing}
\description{Filtering of amplification-biased sites for allele-specific analysis of ChIP-seq data.}
\details{
\tabular{ll}{
Package: \tab absfilter\cr
Type: \tab Package\cr
Version: \tab 1.0\cr
Date: \tab 2013-07-24\cr
License: \tab GPL (>=3.0)\cr
}
}
\author{
Sebastian M Waszak

Maintainer: Sebastian M Waszak <sebastian.waszak@epfl.ch>
}
\references{
Waszak SM, Kilpinen H, Gschwind A, Orioli A, Raghav SK, Witwicki RM, Migliavacca E, Yurovsky A, Lappalainen T, Hernandez N, Reymond A, Dermitzakis ET, Deplancke B. Identification and removal of low-complexity sites in allele-specific analysis of ChIP-seq data. Manuscript submitted.
}
\keyword{ ChIP-seq allele-specific }
\examples{
## download URSS simulation file for 36 bp reads from http://updepla1srv1.epfl.ch/waszaks/ and uncompress it to /path/to/abs/sim/36/

## step 1: load URSS simulations for 36 bp reads (approx. 1GB memory footprint).
absSim36 <- loadSim(path = "/path/to/abs/sim/36/")

## step 2: run ABS filter on example.bam and with the corresponding AS file example.txt
absFiltOut <- absFilter(bamPath = "/path/to/bam/dir/",
                        bamFile = "example.bam",
                        asPath = "/path/to/as/dir/",
                        asFile = "example.txt",
                        absPath = "/path/to/abs/out/dir/",
                        absSim = absSim36)

absFiltOutUnbiasedSites<- absFiltOut$aubs # amplification unbiased sites
absFiltOutBiasedSites<- absFiltOut$abs    # amplification biased sites
nrow(absFiltOutUnbiasedSites)
nrow(absFiltOutBiasedSites)

## (optional) simulate expected URSS distributions for other read length
urssSim(readLen = 51,
        maxReadDepth = 2000,
        numSamples = 1000,
        outPath = "/path/to/abs/sim/51/")

}
